@@ -118,6 +118,7 @@ class UserMetadata(BaseModel):
     created_from_backend: Optional[bool] = True
     st_slack_webhook_url: Optional[str] = None
     sg_slack_webhook_url: Optional[str] = None
+    stripe_customer_id: Optional[str] = None
 
     class Config:
         arbitrary_types_allowed = True
@@ -142,11 +143,13 @@ class CreateSubscriptionInput(BaseModel):
     amount: int
     months: int
     payment_method_type: str
+    use_test_customer: bool = False
 
 
 class TopUpRegularBalanceInput(BaseModel):
     amount: int
     payment_method_type: str
+    use_test_customer: bool = False
 
 
 class UserSubscription(BaseModel):
@@ -159,6 +162,40 @@ class UserSubscription(BaseModel):
     last_refill: str
 
 
+class GPUPrice(BaseModel):
+    normal: float
+    discount: float
+
+
+class GPUPrices(BaseModel):
+    on_demand: GPUPrice
+    spot: GPUPrice
+
+
+class DeploymentType(str, Enum):
+    Job = "Job"
+    InferenceDeployment = "InferenceDeployment"
+    GPUMachine = "GPUMachine"
+
+
+class GPUPricesIn(BaseModel):
+    gpu: GPUType
+    deployment_type: DeploymentType
+    values: GPUPrices
+
+
+class UserGPUPrices(BaseModel):
+    user_id: str
+    prices: dict[str, dict[GPUType, GPUPrices]]
+
+
+class Transaction(BaseModel):
+    amount: float
+    order_type: OrderType
+    status: str
+    created_at: int
+
+
 class SecretOut(BaseModel):
     secret: Dict[str, Any]
     success_status: bool
@@ -191,6 +228,13 @@ class UserRegisterIn(BaseModel):
     productType: ProductType = ProductType.SCALETORCH
     send_welcome_email: Optional[bool] = True
 
+    def __init__(self, **data: Any):
+        email = data.get("email")
+        if email:
+            data["email"] = email.lower()
+
+        super().__init__(**data)
+
 
 class Checkpoint(BaseModel):
     id: str
@@ -465,6 +509,7 @@ class InferenceDeploymentInitialWorkersConfig(BaseModel):
     use_on_prem: Optional[bool] = False
     use_cloudburst: Optional[bool] = False
     on_prem_node_ids: Optional[List[str]] = None
+    expand_gpu_types: Optional[bool] = True
 
 
 class InferenceDeploymentAutoscalingStrategy(str, Enum):
@@ -552,6 +597,7 @@ class InferenceDeploymentIn(BaseModel):
     controller_on_prem_config: Optional[InferenceControllerOnPremConfig] = None
 
     llm_loras: Optional[List[LLMLoraConfig]] = []
+    max_model_len: Optional[int] = None
 
     def __init__(self, **data: Any):
         # Validate that controller_cloud_config or controller_on_prem_config is provided
@@ -620,6 +666,8 @@ class InferenceDeploymentUpdateIn(BaseModel):
     min_throughput_rate: Optional[float] = None
     allow_spot_instances: Optional[bool] = None
 
+    llm_loras: Optional[List[LLMLoraConfig]] = []
+
 
 class InferenceDeploymentGpuNodesIn(BaseModel):
     gpu_nodes_ids: List[str]
@@ -634,6 +682,54 @@ class InferenceDeploymentStatus(str, Enum):
     DELETING = "DELETING"
 
 
+default_engine_strategy_map = {
+    InferenceDeploymentType.vlm: [
+        (
+            InferenceDeploymentEngine.lmdeploy,
+            InferenceDeploymentAutoscalingStrategy.rps_per_worker,
+        ),
+    ],
+    InferenceDeploymentType.llm: [
+        (
+            InferenceDeploymentEngine.vllm,
+            InferenceDeploymentAutoscalingStrategy.ttft_latency_sec,
+        ),
+        (
+            InferenceDeploymentEngine.vllm,
+            InferenceDeploymentAutoscalingStrategy.rps_per_worker,
+        ),
+        (
+            InferenceDeploymentEngine.nim,
+            InferenceDeploymentAutoscalingStrategy.ttft_latency_sec,
+        ),
+        (
+            InferenceDeploymentEngine.nim,
+            InferenceDeploymentAutoscalingStrategy.rps_per_worker,
+        ),
+        (
+            InferenceDeploymentEngine.friendli,
+            InferenceDeploymentAutoscalingStrategy.ttft_latency_sec,
+        ),
+        (
+            InferenceDeploymentEngine.friendli,
+            InferenceDeploymentAutoscalingStrategy.rps_per_worker,
+        ),
+    ],
+    InferenceDeploymentType.embedding: [
+        (
+            InferenceDeploymentEngine.tei,
+            InferenceDeploymentAutoscalingStrategy.rps_per_worker,
+        ),
+    ],
+    InferenceDeploymentType.tti: [
+        (
+            InferenceDeploymentEngine.nos,
+            InferenceDeploymentAutoscalingStrategy.rps_per_worker,
+        )
+    ],
+}
+
+
 class InferenceDeploymentDB(InferenceDeploymentIn):
     id: str
     user_id: str
@@ -645,7 +741,9 @@ class InferenceDeploymentDB(InferenceDeploymentIn):
     link: Optional[str] = None
     end_time: Optional[str] = None
     metadata: Optional[Dict[str, Any]] = {}
-    engine: Optional[InferenceDeploymentEngine] = None
+
+    # Making engine non-optional
+    engine: InferenceDeploymentEngine  # type: ignore
 
     def __init__(self, **data: Any):
         # Patch for existing records in DB that do not have controller_cloud_config or controller_on_prem_config
@@ -656,6 +754,9 @@ class InferenceDeploymentDB(InferenceDeploymentIn):
                 cloud_provider=ProviderEnum.AWS, region="us-east-1"
             ).model_dump(mode="json")
 
+        if not data.get("engine", None):
+            data["engine"] = default_engine_strategy_map[data["inf_type"]][0][0]
+
         super().__init__(**data)
 
 
@@ -991,3 +1092,17 @@ class GPUMachineDB(GPUMachineCreateIn):
     status: GPUMachineStatus
     timestamp: str
     instance_details: InstancePricingDB
+    end_time: Optional[str] = None
+    last_cost_updated_time: Optional[str] = None
+    cost: float = 0
+
+
+class DNSRecordIn(BaseModel):
+    inf_id: str
+    controller_ip: str
+
+
+class DNSGetCertOut(BaseModel):
+    cert_file: str
+    key_file: str
+    cert_chain_file: str
