@@ -71,6 +71,7 @@ class InferenceDeploymentEngine(str, Enum):
     nim = "nim"
     lmdeploy = "lmdeploy"
     nos = "nos"
+    friendli = "friendli"
 
 
 class ProductType(str, Enum):
@@ -131,10 +132,32 @@ class GPUType(str, Enum):
     A10G = "A10G"
     A30 = "A30"
     A40 = "A40"
+
+    # A100 (40GB)
+    # When just A100 is mentioned, it is assumed to be 40GB
+    # We will also include SXM and NVLINK versions when only A100 is mentioned in API or JC
+    # The same applies to H100_80GB and A100_80GB
     A100 = "A100"
+    A100_PCIE = "A100_PCIE"  # PCIE
+    A100_SXM = "A100_SXM"  # SXM
+    A100_PCIE_NVLINK = "A100_PCIE_NVLINK"  # PCIE with NVLINK
+    A100_SXM_NVLINK = "A100_SXM_NVLINK"  # SXM with NVLINK
+
+    # A100_80GB
     A100_80GB = "A100_80GB"
-    GH201 = "GH201"
+    A100_80GB_PCIE = "A100_80GB_PCIE"  # PCIE
+    A100_80GB_SXM = "A100_80GB_SXM"  # SXM
+    A100_80GB_PCIE_NVLINK = "A100_80GB_PCIE_NVLINK"  # PCIE with NVLINK
+    A100_80GB_SXM_NVLINK = "A100_80GB_SXM_NVLINK"  # SXM with NVLINK
+
+    # H100_80GB
     H100_80GB = "H100_80GB"
+    H100_80GB_PCIE = "H100_80GB_PCIE"  # PCIE
+    H100_80GB_SXM = "H100_80GB_SXM"  # SXM
+    H100_80GB_PCIE_NVLINK = "H100_80GB_PCIE_NVLINK"  # PCIE with NVLINK
+    H100_80GB_SXM_NVLINK = "H100_80GB_SXM_NVLINK"  # SXM with NVLINK
+
+    GH201 = "GH201"
     K80 = "K80"
     L4 = "L4"
     L40 = "L40"
@@ -164,6 +187,29 @@ class GPUType(str, Enum):
 
     EMPTY = ""
 
+    def expand_types(self) -> List["GPUType"]:
+        if (
+            self == GPUType.A100
+            or self.value.startswith("A100_")
+            and "80GB" not in self.value
+        ):
+            return [
+                gpu_type
+                for gpu_type in GPUType
+                if gpu_type.value.startswith(max(self.value, "A100_"))
+                and "80GB" not in gpu_type.value
+            ]
+
+        if any(map(self.value.startswith, ["A100_80GB", "H100_80GB"])):
+            return [
+                gpu_type
+                for gpu_type in GPUType
+                if gpu_type.value.startswith(self.value)
+            ]
+
+        else:
+            return [self]
+
 
 on_prem_gpu_type_map = {
     GPUType.A10G: ["a10"],
