@@ -48,6 +48,7 @@ class TaskType(str, Enum):
     SETUP_INF_DEPLOYMENT = "SETUP_INF_DEPLOYMENT"
     DELETE_INF_DEPLOYMENT = "DELETE_INF_DEPLOYMENT"
     SCALE_INF_DEPLOYMENT = "SCALE_INF_DEPLOYMENT"
+    UPDATE_LORA_INF_DEPLOYMENT = "UPDATE_LORA_INF_DEPLOYMENT"
     SETUP_LLM_GATEWAY = "SETUP_LLM_GATEWAY"
     DELETE_LLM_GATEWAY = "DELETE_LLM_GATEWAY"
     SETUP_GPU_MACHINE = "SETUP_GPU_MACHINE"
@@ -124,6 +125,7 @@ task_to_payload_type = {
     TaskType.SETUP_INF_DEPLOYMENT: TaskPayloadBase,
     TaskType.SCALE_INF_DEPLOYMENT: ScaleInferenceDeploymentTaskPayload,
     TaskType.DELETE_INF_DEPLOYMENT: DeleteInferenceTaskPayload,
+    TaskType.UPDATE_LORA_INF_DEPLOYMENT: TaskPayloadBase,
     TaskType.SETUP_LLM_GATEWAY: TaskPayloadBase,
     TaskType.DELETE_LLM_GATEWAY: TaskPayloadBase,
     TaskType.SETUP_GPU_MACHINE: TaskPayloadBase,
@@ -155,6 +157,10 @@ class Task(BaseModel):
 
     def __init__(self, *args, **kwargs):
 
+        # For backwards compatibility or any dev tasks created with no job_id
+        if kwargs["payload"].get("job_id", None) is None:
+            kwargs["payload"]["job_id"] = "dummy_job_id"
+
         # Create the payload of right type
         if isinstance(kwargs["payload"], TaskPayloadBase):
             kwargs["payload"] = kwargs["payload"].model_dump(mode="json")
