@@ -92,7 +92,7 @@ def create_ft_job(ft_req_data: FinetuningIn, quiet: bool = False):
         return
 
     if not quiet:
-        display_event_logs(job_id)
+        display_event_logs(job_id, ft_type="clm")
 
 
 @clm.command(
@@ -109,7 +109,7 @@ def create_ft_job(ft_req_data: FinetuningIn, quiet: bool = False):
     "--base_model",
     required=False,
     type=click.STRING,
-    help="Base model to use. Model must be compatible with base model. If base model is not specified, model will be used.",
+    help="Base model to use. Model must be compatible with base model. If base model is not specified, `--model` value will be used.",
 )
 @click.option(
     "--finetuning_type",
@@ -132,11 +132,10 @@ def create_ft_job(ft_req_data: FinetuningIn, quiet: bool = False):
     help="Specify Weights & Biases key to track experiments.",
 )
 @click.option(
-    "--cometml_key",
+    "--comet_ml_key",
     required=False,
     type=click.STRING,
-    help="Specify Comet ML key to track experiments. "
-    + click.style("NOTE: Currently not supported!", italic=True),
+    help="Specify Comet ML key to track experiments.",
 )
 @click.option(
     "--hf_token", required=False, type=click.STRING, help="Hugging Face token to use."
@@ -172,7 +171,7 @@ def create_ft_job(ft_req_data: FinetuningIn, quiet: bool = False):
     cls=CategorizedMutuallyExclusiveOption,
     required=True,
     type=click.STRING,
-    help="Data path to use. Can be a hugging face dataset or name of a virtual mount (filename is set with user_dataset).",
+    help="Data path to use. Can be a hugging face dataset or name of a virtual mount (filename is set with `--user_dataset`).",
     category="Dataset configuration options",
 )
 @click.option(
@@ -180,7 +179,7 @@ def create_ft_job(ft_req_data: FinetuningIn, quiet: bool = False):
     cls=CategorizedMutuallyExclusiveOption,
     required=False,
     type=click.STRING,
-    help="Filename of a dataset on virtual mount to use.",
+    help="Filename of a dataset on virtual mount to use (`--data_path` must be set to a virtual mount name).",
     category="Dataset configuration options",
 )
 @click.option(
@@ -328,7 +327,25 @@ def create_ft_job(ft_req_data: FinetuningIn, quiet: bool = False):
     category="Optimal worker configuration options",
     mutually_exclusive=["gpu_type", "gpu_num", "use_recipes"],
 )
-# ******************************* TRAINNIG CONFIGURATION OPTIONS *******************************
+# ******************************* TRAINING CONFIGURATION OPTIONS *******************************
+@click.option(
+    "--resume_from_checkpoint",
+    cls=CategorizedMutuallyExclusiveOption,
+    required=False,
+    type=click.STRING,
+    help="Checkpoint path to use. Can be a hugging face model name or name of a virtual mount (directory is set with `--user_checkpoint`).",
+    category="Training configuration options",
+)
+@click.option(
+    "--user_checkpoint_dir",
+    cls=CategorizedMutuallyExclusiveOption,
+    required=False,
+    default=DEFAULT_LLM_PARAMS.user_checkpoint_dir,
+    show_default=True,
+    type=click.STRING,
+    help="Dirname of a checkpoint in the specified virtual mount or HF model repository.",
+    category="Training configuration options",
+)
 @click.option(
     "--epochs",
     cls=CategorizedMutuallyExclusiveOption,
@@ -429,6 +446,9 @@ def create_ft_job(ft_req_data: FinetuningIn, quiet: bool = False):
             "constant",
             "constant_with_warmup",
             "inverse_sqrt",
+            "reduce_lr_on_plateau",
+            "cosine_with_min_lr",
+            "warmup_stable_decay",
         ]
     ),
     default=DEFAULT_LLM_PARAMS.lr_scheduler_type,
@@ -575,6 +595,22 @@ def create_ft_job(ft_req_data: FinetuningIn, quiet: bool = False):
     help="Lora dropout to use.",
     category="PEFT options",
 )
+@click.option(
+    "--init_lora_weights",
+    cls=CategorizedMutuallyExclusiveOption,
+    required=False,
+    type=click.Choice(["gaussian", "pissa", "olora"]),
+    help="How to initialize the weights of the adapter layers. Passing nothing (the default) results in the default initialization from the reference implementation from Microsoft. Passing ‘gaussian’ results in Gaussian initialization scaled by the LoRA rank for linear and layers. Pass 'olora' to use OLoRA initialization. Passing 'pissa' to use PiSSa initialization.",
+    category="PEFT options",
+)
+@click.option(
+    "--use_rslora",
+    cls=CategorizedMutuallyExclusiveOption,
+    required=False,
+    is_flag=True,
+    help="When set to True, uses Rank-Stabilized LoRA which sets the adapter scaling factor to lora_alpha/math.sqrt(r), since it was proven to work better. Otherwise, it will use the original default value of lora_alpha/r.",
+    category="PEFT options",
+)
 @click.option(
     "--adalora_init_r",
     cls=CategorizedMutuallyExclusiveOption,
@@ -799,6 +835,7 @@ def create_impl(**finetune_kwargs: Any):
         "model": finetune_kwargs["model"],
         "data_path": finetune_kwargs["data_path"],
         "wandb_key": finetune_kwargs["wandb_key"],
+        "comet_ml_key": finetune_kwargs["comet_ml_key"],
         "hf_token": finetune_kwargs["hf_token"],
         "username": finetune_kwargs["hf_username"],
         "push_to_hub": finetune_kwargs["push_to_hub"],
@@ -859,6 +896,10 @@ def create_impl(**finetune_kwargs: Any):
         "text_column": finetune_kwargs["text_column"],
         "rejected_text_column": finetune_kwargs["rejected_text_column"],
         "use_unsloth": finetune_kwargs["use_unsloth"],
+        "resume_from_checkpoint": finetune_kwargs["resume_from_checkpoint"],
+        "user_checkpoint_dir": finetune_kwargs["user_checkpoint_dir"],
+        "use_rslora": finetune_kwargs["use_rslora"],
+        "init_lora_weights": finetune_kwargs["init_lora_weights"],
     }
     ft_req_data = FinetuningIn(
         **data, autotrain_params=LLMTrainingParams(**autotrain_params)
