@@ -217,7 +217,7 @@ def verify_cloud_config_options(kwargs: Dict[str, Any]):
             exit()
 
         return InferenceControllerCloudConfig(
-            use_public_url=kwargs["use_public_url"],
+            public_url=kwargs["use_public_url"],
             use_ssl=kwargs["use_ssl"],
             use_api_gateway=kwargs["use_api_gateway"],
             vpc_id=kwargs["vpc_id"],
@@ -266,7 +266,8 @@ def create_inf_dep(
 
     if resp.status_code == 200:
         resp_data = resp.json()
-        inf_id = resp_data["message"]["inf_id"]  # P-API returns dict for CREATE request
+        # P-API returns dict for CREATE request
+        inf_id = resp_data["message"]["inf_id"]
         click.echo(click.style(f"Created deployment - Id: {inf_id}", fg="green"))
 
     elif resp.status_code == 500:
@@ -316,16 +317,16 @@ def create_inf_dep(
 )
 @click.option(
     "--inf_type",
-    type=click.Choice(["embedding", "llm", "tti"]),
+    type=click.Choice(["embedding", "llm", "tti", "vlm"]),
     required=True,
     help="Inference deployment type to use.",
 )
 @click.option(
     "--engine",
-    type=click.Choice(["vllm", "tei", "nim"]),
+    type=click.Choice(["vllm", "tei", "nim", "lmdeploy", "nos", "friendli"]),
     required=False,
     default=None,
-    help="Inference engine use.",
+    help="Inference engine to use",
 )
 @click.option(
     "--hf_token",
@@ -381,22 +382,22 @@ def create_inf_dep(
     category="Auto-scaling options",
 )
 @click.option(
-    "--lower_allowed_latency_sec",
+    "--lower_allowed_threshold",
     cls=CategorizedMutuallyExclusiveOption,
     type=click.FLOAT,
     required=False,
-    default=DEFAULT_AUTOSCALING_CONFIG.lower_allowed_latency_sec,
-    help="Lower allowed latency in seconds to use.",
+    default=DEFAULT_AUTOSCALING_CONFIG.lower_allowed_threshold,
+    help="Lower allowed threshold to use. Seconds for ttft strategy and RPS for rps_per_worker strategy.",
     category="Auto-scaling options",
     show_default=True,
 )
 @click.option(
-    "--upper_allowed_latency_sec",
+    "--upper_allowed_threshold",
     cls=CategorizedMutuallyExclusiveOption,
     type=click.FLOAT,
     required=False,
-    default=DEFAULT_AUTOSCALING_CONFIG.upper_allowed_latency_sec,
-    help="Upper allowed latency in seconds to use.",
+    default=DEFAULT_AUTOSCALING_CONFIG.upper_allowed_threshold,
+    help="Lower allowed threshold to use. Seconds for ttft strategy and RPS for rps_per_worker strategy.",
     category="Auto-scaling options",
     show_default=True,
 )
@@ -515,6 +516,14 @@ def create_inf_dep(
     category="Options responsible for optimal worker configuration",
     mutually_exclusive=["min_throughput_rate"],
 )
+@click.option(
+    "--expand_gpu_types",
+    cls=CategorizedMutuallyExclusiveOption,
+    is_flag=True,
+    help="For A100, H100 GPUs, this option when set includes PCIE, SXM and NVLINK variants.",
+    category="Options responsible for optimal worker configuration",
+    mutually_exclusive=["min_throughput_rate"],
+)
 @click.option(
     "--instance_types",
     cls=CategorizedMutuallyExclusiveOption,
@@ -610,6 +619,13 @@ def create_inf_dep(
     show_default=True,
     multiple=True,
 )
+# ******************************* Miscellaneous options *******************************
+@click.option(
+    "--max_model_len",
+    type=int,
+    required=False,
+    help="Max Sequence length to be used by the inference engine",
+)
 @click.option("-f", "--force", is_flag=True)
 @click.option("-q", "--quiet", is_flag=True)
 def create_impl(**inference_kwargs: Any):
@@ -617,6 +633,17 @@ def create_impl(**inference_kwargs: Any):
     Create an inference deployment
     """
 
+    if inference_kwargs["min_workers"] > 0 and inference_kwargs["scale_to_zero"]:
+        click.echo(
+            click.style(
+                f"\nUsing two conflicting arguments --min_workers and --scale_to_zero. "
+                f"To solve conflict disable --scale_to_zero option or set --min_workers to 0 (default value).",
+                fg="red",
+            ),
+            err=True,
+        )
+        exit()
+
     # Verify controller_config
     controller_config = verify_cloud_config_options(inference_kwargs)
 
@@ -693,6 +720,7 @@ def create_impl(**inference_kwargs: Any):
                 "use_same_gpus_when_scaling"
             ],
             "instance_types": inference_kwargs["instance_types"],
+            "expand_gpu_types": inference_kwargs["expand_gpu_types"],
         },
         "autoscaling_config": {
             "enable_fast_autoscaling": inference_kwargs["enable_fast_autoscaling"],
@@ -701,8 +729,8 @@ def create_impl(**inference_kwargs: Any):
             "scale_down_time_window_sec": inference_kwargs[
                 "scale_down_time_window_sec"
             ],
-            "upper_allowed_latency_sec": inference_kwargs["upper_allowed_latency_sec"],
-            "lower_allowed_latency_sec": inference_kwargs["lower_allowed_latency_sec"],
+            "upper_allowed_threshold": inference_kwargs["upper_allowed_threshold"],
+            "lower_allowed_threshold": inference_kwargs["lower_allowed_threshold"],
             "scaling_up_timeout_sec": inference_kwargs["scaling_up_timeout_sec"],
             "scaling_down_timeout_sec": inference_kwargs["scaling_down_timeout_sec"],
             "scale_to_zero_timeout_sec": inference_kwargs["scale_to_zero_timeout_sec"],
@@ -720,6 +748,7 @@ def create_impl(**inference_kwargs: Any):
         ),
         "max_price_per_hour": inference_kwargs["max_price_per_hour"],
         "min_throughput_rate": inference_kwargs["min_throughput_rate"],
+        "max_model_len": inference_kwargs["max_model_len"],
     }
 
     inf_dep_req_data = InferenceDeploymentIn(**data)
@@ -743,6 +772,7 @@ def launch_impl(config_file, force, quiet):
     Launch an inference deployment using a config YAML file
     """
     # check if config_file is an absolute path
+    config_path = config_file
     if not os.path.isabs(config_file):
         config_path = os.path.join(os.getcwd(), config_file)
 
@@ -965,13 +995,25 @@ def view_impl(inf_id: str):
 
     url = inf_dep.get("link", "")
     if url:
-        if inf_dep["inf_type"] in ["llm", "tti"]:
+        if inf_dep["inf_type"] in ["llm", "tti", "vlm"]:
             url += "/inference"
         else:
             url += "inference/embed"
     markdown_content += (
         f"[orange_red1]Endpoint[/orange_red1] : [yellow]{url}[/yellow]\n"
     )
-    markdown_content += f"[orange_red1]APIKey[/orange_red1] : [yellow]{get_garb('AUTH_ENDPOINT_KEY_' + inf_id)}[/yellow]\n"
-
+    markdown_content += f"[orange_red1]APIKey[/orange_red1] : [yellow]{get_garb('AUTH_ENDPOINT_KEY_' + inf_id)}[/yellow]\n\n"
+    markdown_content += (
+        f"[bold underline magenta]Autoscaling Configuration[/bold underline magenta]\n"
+    )
+    markdown_content += f"[orange_red1]Autoscaling strategy [/orange_red1] : [yellow]{inf_dep['autoscaling_config']['autoscaling_strategy']}[/yellow]\n"
+    markdown_content += f"[orange_red1]Scale-up Time Window (sec)[/orange_red1] : [yellow]{inf_dep['autoscaling_config']['scale_up_time_window_sec']}[/yellow]\n"
+    markdown_content += f"[orange_red1]Scale-down Time Window (sec)[/orange_red1] : [yellow]{inf_dep['autoscaling_config']['scale_down_time_window_sec']}[/yellow]\n"
+    markdown_content += f"[orange_red1]Scale to zero (sec)[/orange_red1] : [yellow]{inf_dep['autoscaling_config']['scale_to_zero']}[/yellow]\n\n"
+    markdown_content += (
+        f"[bold underline magenta]Worker Configuration[/bold underline magenta]\n"
+    )
+    markdown_content += f"[orange_red1]Minimum workers[/orange_red1] : [yellow]{inf_dep['initial_worker_config']['min_workers']}[/yellow]\n"
+    markdown_content += f"[orange_red1]Maximum price per hr[/orange_red1] : [yellow]{inf_dep['max_price_per_hour']}[/yellow]\n"
+    markdown_content += f"[orange_red1]Allow spot instances[/orange_red1] : [yellow]{inf_dep['allow_spot_instances']}[/yellow]\n"
     console.print(Panel(markdown_content))
